import { scaleLinear, extent } from 'd3';
import { axes } from './axes';

export const viz = (
  selection,
  {
    data,
    xValue,
    yValue,
    width,
    height,
    margin,
    circleRadius,
  }
) => {
  const { top, right, bottom, left } = margin;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([left, width - right]);

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - bottom, top]);

  selection
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('r', circleRadius)
    .attr('fill-opacity', 0.5)
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)));

  axes(selection, {
    height,
    margin,
    xScale,
    yScale,
  });
};
